# Package Information

Before install, please make sure you have installed a running LaTex. 
Please follow the instructions to install MikTex:
https://miktex.org/download

For GPU acceleration, please check you have installed CUDA version >= 10.1.
